32-bit checksums
================
.. automodule:: numcodecs.checksum32

CRC32
-----
.. autoclass:: CRC32

    .. autoattribute:: codec_id
    .. automethod:: encode
    .. automethod:: decode
    .. automethod:: get_config
    .. automethod:: from_config


Adler32
-------
.. autoclass:: Adler32

    .. autoattribute:: codec_id
    .. automethod:: encode
    .. automethod:: decode
    .. automethod:: get_config
    .. automethod:: from_config
